# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::LR;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20160304153311;

my $formatters = [
                {
                  'pattern' => '(2\\d)(\\d{3})(\\d{3})',
                  'leading_digits' => '2'
                },
                {
                  'pattern' => '(\\d{3})(\\d{3})(\\d{3})',
                  'leading_digits' => '[2579]'
                },
                {
                  'pattern' => '([4-6])(\\d{3})(\\d{3})',
                  'leading_digits' => '[4-6]'
                },
                {
                  'pattern' => '(\\d{2})(\\d{3})(\\d{4})',
                  'leading_digits' => '[38]'
                }
              ];

my $validators = {
                'personal_number' => '',
                'pager' => '',
                'mobile' => '
          (?:
            330\\d|
            4[67]|
            5\\d|
            77\\d{2}|
            88\\d{2}|
            994\\d
          )\\d{5}|
          (?:
            20\\d{3}|
            33(?:
                0\\d{2}|
                2(?:
                   02|
                   5\\d
                )
            )|
            555\\d{2}|
            77[0567]\\d{2}|
            88[068]\\d{2}|
            994\\d{2}
          )\\d{4}
        ',
                'specialrate' => '(90[03]\\d{6})',
                'fixed_line' => '2\\d{7}',
                'voip' => '
          332(?:
            0[02]|
            5\\d
          )\\d{4}
        ',
                'toll_free' => '',
                'geographic' => '2\\d{7}'
              };

sub new {
  my $class = shift;
  my $number = shift;
  $number =~ s/(^\+231|\D)//g;
  my $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self if ($self->is_valid());
  $number =~ s/(^0)//g;
  $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self->is_valid() ? $self : undef;
}

1;
