# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::BQ;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20160304153310;

my $formatters = [];

my $validators = {
                'toll_free' => '',
                'geographic' => '
          (?:
            318[023]|
            416[023]|
            7(?:
              1[578]|
              50
            )\\d
          )\\d{3}
        ',
                'specialrate' => '',
                'fixed_line' => '
          (?:
            318[023]|
            416[023]|
            7(?:
              1[578]|
              50
            )\\d
          )\\d{3}
        ',
                'voip' => '',
                'personal_number' => '',
                'pager' => '',
                'mobile' => '
          (?:
            318[14-68]|
            416[15-9]|
            7(?:
              0[01]|
              7[07]|
              [89]\\d
            )\\d
          )\\d{3}
        '
              };
sub areaname { my $self = shift; my $number = $self->{number}; my %map = (
  599318 => "St\.\ Eustatius",
  599416 => "Saba",
  599715 => "Bonaire",
  599717 => "Bonaire",
  599718 => "Bonaire",
  599750 => "Bonaire",
);
      foreach my $prefix (map { substr($number, 0, $_) } reverse(1..length($number))) {
        return $map{"599$prefix"} if exists($map{"599$prefix"});
      }
      return undef;
    }
sub new {
  my $class = shift;
  my $number = shift;
  $number =~ s/(^\+599|\D)//g;
  my $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self->is_valid() ? $self : undef;
}

1;
