# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::GW;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20160304153311;

my $formatters = [
                {
                  'leading_digits' => '
            44|
            9[567]
          ',
                  'pattern' => '(\\d{3})(\\d{3})(\\d{3})'
                },
                {
                  'pattern' => '(\\d{3})(\\d{4})',
                  'leading_digits' => '40'
                }
              ];

my $validators = {
                'geographic' => '
          443(?:
              2[0125]|
              3[1245]|
              4[12]|
              5[1-4]|
              70|
              9[1-467]
            )\\d{4}
        ',
                'toll_free' => '',
                'personal_number' => '',
                'mobile' => '
          9(?:
            55\\d|
            6(?:
              6\\d|
              9[012]
            )|
            77\\d
          )\\d{5}
        ',
                'pager' => '',
                'fixed_line' => '
          443(?:
              2[0125]|
              3[1245]|
              4[12]|
              5[1-4]|
              70|
              9[1-467]
            )\\d{4}
        ',
                'specialrate' => '',
                'voip' => '40\\d{5}'
              };
sub areaname { my $self = shift; my $number = $self->{number}; my %map = (
  24544320 => "Bissau",
  24544321 => "Bissau",
  24544322 => "St\.\ Luzia",
  24544325 => "Brá",
  24544331 => "Mansôa",
  24544332 => "Bissora",
  24544334 => "Mansaba",
  24544335 => "Farim",
  24544341 => "Bafatá",
  24544342 => "Bambadinca",
  24544351 => "Gabu",
  24544352 => "Sonaco",
  24544353 => "Pirada",
  24544354 => "Pitche",
  24544370 => "Buba",
  24544391 => "Canchungo",
  24544392 => "Cacheu",
  24544393 => "S\.\ Domingos",
  24544394 => "Bula",
  24544396 => "Ingoré",
  24544397 => "Bigene",
);
      foreach my $prefix (map { substr($number, 0, $_) } reverse(1..length($number))) {
        return $map{"245$prefix"} if exists($map{"245$prefix"});
      }
      return undef;
    }
sub new {
  my $class = shift;
  my $number = shift;
  $number =~ s/(^\+245|\D)//g;
  my $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self->is_valid() ? $self : undef;
}

1;
