# automatically generated file, don't edit



# Copyright 2011 David Cantrell, derived from data from libphonenumber
# http://code.google.com/p/libphonenumber/
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
package Number::Phone::StubCountry::BB;
use base qw(Number::Phone::StubCountry);

use strict;
use warnings;
use utf8;
our $VERSION = 1.20160304153310;

my $formatters = [
                {
                  'pattern' => '(\\d{3})(\\d{4})'
                },
                {
                  'pattern' => '(\\d{3})(\\d{3})(\\d{4})'
                }
              ];

my $validators = {
                'geographic' => '
          246(?:
              2(?:
                2[78]|
                7[0-4]
              )|
              4(?:
                1[024-6]|
                2\\d|
                3[2-9]
              )|
              5(?:
                20|
                [34]\\d|
                54|
                7[1-3]
              )|
              6(?:
                2\\d|
                38
              )|
              7(?:
                37|
                57
              )|
              9(?:
                1[89]|
                63
              )
          )\\d{4}
        ',
                'toll_free' => '
          8(?:
            00|
            44|
            55|
            66|
            77|
            88
          )[2-9]\\d{6}
        ',
                'voip' => '24631\\d{5}',
                'fixed_line' => '
          246(?:
              2(?:
                2[78]|
                7[0-4]
              )|
              4(?:
                1[024-6]|
                2\\d|
                3[2-9]
              )|
              5(?:
                20|
                [34]\\d|
                54|
                7[1-3]
              )|
              6(?:
                2\\d|
                38
              )|
              7(?:
                37|
                57
              )|
              9(?:
                1[89]|
                63
              )
          )\\d{4}
        ',
                'specialrate' => '(
          900\\d{7}|
          246976\\d{4}
        )|(
          246(?:
              292|
              41[7-9]|
              43[01]
          )\\d{4}
        )',
                'mobile' => '
          246(?:
              2(?:
                [356]\\d|
                4[0-57-9]|
                8[0-79]
              )|
              45\\d|
              8(?:
                [2-5]\\d|
                83
              )
          )\\d{4}
        ',
                'pager' => '',
                'personal_number' => '
          5(?:
            00|
            33|
            44|
            66|
            77|
            88
          )[2-9]\\d{6}
        '
              };
use Number::Phone::NANP::Data;sub areaname { Number::Phone::NANP::Data::areaname('1'.shift()->{number}); }

sub new {
  my $class = shift;
  my $number = shift;
  $number =~ s/(^\+1|\D)//g;
  my $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self if ($self->is_valid());
  $number =~ s/(^1)//g;
  $self = bless({ number => $number, formatters => $formatters, validators => $validators }, $class);
  return $self->is_valid() ? $self : undef;
}

1;
